@@ -9,11 +9,10 @@ from datetime import datetime
 from repominer.files import FixedFileEncoder, FixedFileDecoder, FailureProneFileEncoder, FailureProneFileDecoder
 from repominer.metrics.ansible import AnsibleMetricsExtractor
 from repominer.metrics.tosca import ToscaMetricsExtractor
-from repominer.mining.base import BaseMiner
 from repominer.mining.ansible import AnsibleMiner
 from repominer.mining.tosca import ToscaMiner
 
-VERSION = '0.8.12'
+VERSION = '0.9.0'
 
 
 def valid_dir_or_url(x: str) -> str:
@@ -75,7 +74,7 @@ def set_mine_parser(subparsers):
 
     parser.add_argument(action='store',
                         dest='repository',
-                        help='the repository full name: <onwer/name> (e.g., radon-h2020/radon-repository-miner)')
+                        help='the repository full name: <owner/name> (e.g., radon-h2020/radon-repository-miner)')
 
     parser.add_argument(action='store',
                         dest='dest',
@@ -170,115 +169,112 @@ def get_parser():
     return parser
 
 
-def mine_fixing_commits(miner: BaseMiner, verbose: bool, dest: str, exclude_commits: str = None, include_commits: str = None):
+class MinerCLI:
 
-    if exclude_commits:
-        with open(exclude_commits, 'r') as f:
-            commits = json.load(f)
-            miner.exclude_commits = set(commits)
+    def __init__(self, args: Namespace):
+        self.args = args
 
-    if include_commits:
-        with open(include_commits, 'r') as f:
-            commits = json.load(f)
-            miner.fixing_commits = commits
+        if args.host == 'github':
+            url_to_repo = f'https://github.com/{args.repository}'
+        elif args.host == 'gitlab':
+            url_to_repo = f'https://gitlab.com/{args.repository}'
+        else:
+            raise ValueError(f'Host {args.host} not supported. Please select github or gitlab')
 
-    if verbose:
-        print('Identifying fixing-commits from closed issues related to bugs')
+        if args.language == 'ansible':
+            self.miner = AnsibleMiner(url_to_repo=url_to_repo, branch=args.branch)
+        else:
+            self.miner = ToscaMiner(url_to_repo=url_to_repo, branch=args.branch)
 
-    from_issues = miner.get_fixing_commits_from_closed_issues(labels=None)
+    def mine(self):
 
-    if verbose:
-        print('Identifying fixing-commits from commit messages')
+        if self.args.verbose:
+            print(f'Mining {self.args.repository} [started at: {datetime.now().hour}:{datetime.now().minute}]')
 
-    from_msg = miner.get_fixing_commits_from_commit_messages(regex=None)
+        self.mine_fixing_commits()
 
-    if verbose:
-        print(f'Saving {len(miner.fixing_commits)} fixing-commits ({len(from_issues)} from closed issue, {len(from_msg)} from commit messages) [{datetime.now().hour}:{datetime.now().minute}]')
+        if self.args.info_to_mine in ('fixed-files', 'failure-prone-files'):
+            self.mine_fixed_files()
 
-    filename_json = os.path.join(dest, 'fixing-commits.json')
+        if self.args.info_to_mine == 'failure-prone-files':
+            self.mine_failure_prone_files()
 
-    with io.open(filename_json, "w") as f:
-        json.dump(miner.fixing_commits, f)
+        exit(0)
 
-    if verbose:
-        print(f'JSON created at {filename_json}')
+    def mine_fixing_commits(self):
 
+        if self.args.exclude_commits:
+            with open(self.args.exclude_commits, 'r') as f:
+                commits = json.load(f)
+                self.miner.exclude_commits = set(commits)
 
-def mine_fixed_files(miner: BaseMiner, verbose: bool, dest: str, exclude_files: str = None):
+        if self.args.include_commits:
+            with open(self.args.include_commits, 'r') as f:
+                commits = json.load(f)
+                self.miner.fixing_commits = commits
 
-    if exclude_files:
-        with open(exclude_files, 'r') as f:
-            files = json.load(f, cls=FixedFileDecoder)
-            miner.exclude_fixed_files = files
+        if self.args.verbose:
+            print('Identifying fixing-commits')
 
-    if verbose:
-        language = 'Ansible' if isinstance(miner, AnsibleMiner) else 'Tosca'
-        print(f'Identifying {language} files modified in fixing-commits')
+        fixing_commits = self.miner.get_fixing_commits()
 
-    fixed_files = miner.get_fixed_files()
+        if self.args.verbose:
+            print(f'Saving {len(fixing_commits)} fixing-commits [{datetime.now().hour}:{datetime.now().minute}]')
 
-    if verbose:
-        print(f'Saving {len(fixed_files)} fixed-files [{datetime.now().hour}:{datetime.now().minute}]')
+        filename_json = os.path.join(self.args.dest, 'fixing-commits.json')
 
-    filename_json = os.path.join(dest, 'fixed-files.json')
-    json_files = []
-    for file in fixed_files:
-        json_files.append(FixedFileEncoder().default(file))
+        with io.open(filename_json, "w") as f:
+            json.dump(fixing_commits, f)
 
-    with io.open(filename_json, "w") as f:
-        json.dump(json_files, f)
+        if self.args.verbose:
+            print(f'JSON created at {filename_json}')
 
-    if verbose:
-        print(f'JSON created at {filename_json}')
+    def mine_fixed_files(self):
 
+        if self.args.exclude_files:
+            with open(self.args.exclude_files, 'r') as f:
+                files = json.load(f, cls=FixedFileDecoder)
+                self.miner.exclude_fixed_files = files
 
-def mine_failure_prone_files(miner: BaseMiner, verbose: bool, dest: str):
-    if verbose:
-        print('Identifying and labeling failure-prone files')
+        if self.args.verbose:
+            print(f'Identifying {self.args.language} files modified in fixing-commits')
 
-    failure_prone_files = [copy.deepcopy(file) for file in miner.label()]
+        fixed_files = self.miner.get_fixed_files()
 
-    if verbose:
-        print('Saving failure-prone files')
+        if self.args.verbose:
+            print(f'Saving {len(fixed_files)} fixed-files [{datetime.now().hour}:{datetime.now().minute}]')
 
-    filename_json = os.path.join(dest, 'failure-prone-files.json')
+        filename_json = os.path.join(self.args.dest, 'fixed-files.json')
+        json_files = []
+        for file in fixed_files:
+            json_files.append(FixedFileEncoder().default(file))
 
-    json_files = []
-    for file in failure_prone_files:
-        json_files.append(FailureProneFileEncoder().default(file))
+        with io.open(filename_json, "w") as f:
+            json.dump(json_files, f)
 
-    with open(filename_json, "w") as f:
-        json.dump(json_files, f)
+        if self.args.verbose:
+            print(f'JSON created at {filename_json}')
 
-    if verbose:
-        print(f'JSON created at {filename_json}')
+    def mine_failure_prone_files(self):
+        if self.args.verbose:
+            print('Identifying and labeling failure-prone files')
 
+        failure_prone_files = [copy.deepcopy(file) for file in self.miner.label()]
 
-def mine(args: Namespace):
-    url_to_repo = None
+        if self.args.verbose:
+            print('Saving failure-prone files')
 
-    if args.host == 'github':
-        url_to_repo = f'https://github.com/{args.repository}'
-    elif args.host == 'gitlab':
-        url_to_repo = f'https://gitlab.com/{args.repository}'
+        filename_json = os.path.join(self.args.dest, 'failure-prone-files.json')
 
-    if args.verbose:
-        print(f'Mining {args.repository} [started at: {datetime.now().hour}:{datetime.now().minute}]')
+        json_files = []
+        for file in failure_prone_files:
+            json_files.append(FailureProneFileEncoder().default(file))
 
-    if args.language == 'ansible':
-        miner = AnsibleMiner(url_to_repo=url_to_repo, branch=args.branch)
-    else:
-        miner = ToscaMiner(url_to_repo=url_to_repo, branch=args.branch)
+        with open(filename_json, "w") as f:
+            json.dump(json_files, f)
 
-    mine_fixing_commits(miner, args.verbose, args.dest, args.exclude_commits, args.include_commits)
-
-    if args.info_to_mine in ('fixed-files', 'failure-prone-files'):
-        mine_fixed_files(miner, args.verbose, args.dest, args.exclude_files)
-
-    if args.info_to_mine == 'failure-prone-files':
-        mine_failure_prone_files(miner, args.verbose, args.dest)
-
-    exit(0)
+        if self.args.verbose:
+            print(f'JSON created at {filename_json}')
 
 
 def extract_metrics(args: Namespace):
@@ -317,6 +313,6 @@ def extract_metrics(args: Namespace):
 def main():
     args = get_parser().parse_args()
     if args.command == 'mine':
-        mine(args)
+        MinerCLI(args).mine()
     elif args.command == 'extract-metrics':
         extract_metrics(args)
